======
HighIQ
======

This software conducts radar and lidar doppler spectra processing using the GPU. Complex autocorrelation
functions are converted to Doppler spectra and moments using CuPy, a NumPy-like interface for CUDA. A
CUDA-compatible GPU is required.

* Free software: 3-clause BSD license

In order to use HighIQ, you must install the version of CuPy for your
specific version of CUDA. In order to do so, follow the link below:

https://docs.cupy.dev/en/stable/install.html
